'use strict'

require("should");


describe("QueryBuilder", function() {
	it("serialize", function(){
		let DbHelper = require("../lib/db_helper.js");

		let qb = DbHelper.createQueryBuilder("abc");
		qb.fields("id,name")
		.where("id", ">", 2)
		.where("name", "LIKE", '%a')
		.order("id", "desc")
		.order("updated", "asc")
		.limit(50, 10)
		;

		let code = qb.serialize();

		let qb2 = DbHelper.unserializeQueryBuilder(code);

		let queryStr = qb2.toQueryStr();
		queryStr.should.eql("SELECT `id`,`name` FROM `abc` WHERE `id` > 2 AND `name` LIKE '%a' ORDER BY `id` desc,`updated` asc LIMIT 50,10");
	});

	it("groupby", function(){
		let DbHelper = require("../lib/db_helper.js");

		let qb = DbHelper.createQueryBuilder("room_user_stat");
		qb.fields("yymmdd")
		.group("yymmdd")
		.order("yymmdd", "desc")
		.limit(0, 30)
		;

		let queryStr = qb.toQueryStr();
		queryStr.should.eql("SELECT `yymmdd` FROM `room_user_stat` GROUP BY `yymmdd` ORDER BY `yymmdd` desc LIMIT 0,30");
	});

	it("select", function(){
		let DbHelper = require("../lib/db_helper.js");

		let qb = DbHelper.createQueryBuilder("abc");
		qb.fields("id,name")
		.where("id", ">", 2)
		.where("name", "LIKE", '%a')
		.order("id", "desc")
		.order("updated", "asc")
		.limit(50, 10)
		;

		let queryStr = qb.toQueryStr();
		queryStr.should.eql("SELECT `id`,`name` FROM `abc` WHERE `id` > 2 AND `name` LIKE '%a' ORDER BY `id` desc,`updated` asc LIMIT 50,10");
	});

	it("insert", function(){
		let DbHelper = require("../lib/db_helper.js");

		let qb = DbHelper.createQueryBuilder("abc");
		qb.add("name", "tester")
		.add("created", 1234567890)
		;

		let str = qb.toInsertStr();
		str.should.eql("INSERT INTO `abc` (`name`,`created`) VALUES('tester',1234567890)");
	});

	it("update", function(){
		let DbHelper = require("../lib/db_helper.js");

		let qb = DbHelper.createQueryBuilder("abc");
		qb.set("name", "tester2")
		.set("update", 19876543210)
		.where("id", "=", 2)
		;

		let str = qb.toUpdateStr();
		str.should.eql("UPDATE `abc` SET `name`='tester2',`update`=19876543210 WHERE `id` = 2");
	});

	it("delete", function(){
		let DbHelper = require("../lib/db_helper.js");

		let qb = DbHelper.createQueryBuilder("abc");
		qb.where("id", "=", 2)
		;

		let str = qb.toDeleteStr();
		str.should.eql("DELETE FROM `abc` WHERE `id` = 2");
	});
});
